@@ -14,6 +14,10 @@ def endpoints():
     return [
         ('http://example.org', 'example.org', 80, False),
         ('https://example.org', 'example.org', 443, True),
+        ('https://[e40:92be:ab1c:c9c1:3e2e:dbf6:57c6:8922]', '[e40:92be:ab1c:c9c1:3e2e:dbf6:57c6:8922]', 443, True),
+        ('http://[e40:92be:ab1c:c9c1:3e2e:dbf6:57c6:8922]', '[e40:92be:ab1c:c9c1:3e2e:dbf6:57c6:8922]', 80, False),
+        ('http://[e39:92be:ab1c:c9c1:3e2e:dbf6:57c6:8922]:8080', '[e39:92be:ab1c:c9c1:3e2e:dbf6:57c6:8922]', 8080, False),
+        ('http://e40:92be:ab1c:c9c1:3e2e:dbf6:57c6:8922', '[e40:92be:ab1c:c9c1:3e2e:dbf6:57c6:8922]', 80, False),
         ('https://example.org:8080', 'example.org', 8080, True),
         ('https://example.org:8080/', 'example.org', 8080, True),
         ('http://example.org:81/a/b/c?b#d', 'example.org', 81, False),
@@ -176,6 +180,7 @@ def test_endpoint_port_specified():
     endpoint = client.Endpoint('example.org', 443, True)
     assert endpoint.port == 443
 
+
 def test_endpoint_equality():
     default_port = client.Endpoint('a.org', None, True)
     secure = client.Endpoint('a.org', 443, True)
@@ -184,6 +189,7 @@ def test_endpoint_equality():
     assert secure == insecure
     assert insecure == default_port
 
+
 def test_endpoint_inequality():
     base = client.Endpoint('a.org', 80, True)
     diff_host = client.Endpoint('b.org', 80, True)
@@ -585,7 +591,6 @@ class TestClientListObjectsInBucket(object):
         assert obj['owner'] == owner
 
 
-
 class TestClientGetWorkerBound(object):
 
     def setup(self):
@@ -645,3 +650,29 @@ class TestClientGetWorkerBound(object):
         assert result['marker'] == " "
         assert result['retries'] == []
         assert result['oldest_time'] == DEFAULT_TIME
+
+
+class TestIsVersioned(object):
+
+    def setup(self):
+        # set strict attributes in the mock
+        self.obj = Mock(spec=object)
+
+    def test_is_in_fact_versioned(self):
+        self.obj.VersionedEpoch = u'1'
+        self.obj.version_id = 'somehashvalue'
+        assert client.is_versioned(self.obj) is True
+
+    def test_is_not_versioned_no_attr_versioned_epoch(self):
+        assert client.is_versioned(self.obj) is False
+
+    def test_is_not_versioned_no_attr_version_id(self):
+        assert client.is_versioned(self.obj) is False
+
+    def test_is_versioned_version_id(self):
+        self.obj.version_id = 1
+        assert client.is_versioned(self.obj) is True
+
+    def test_is_not_versioned_versioned_id_is_none(self):
+        self.obj.version_id = None
+        assert client.is_versioned(self.obj) is False
